@@ -2,7 +2,7 @@
 
 ;;; File: "gambit#.scm"
 
-;;; Copyright (c) 2005-2018 by Marc Feeley, All Rights Reserved.
+;;; Copyright (c) 2005-2019 by Marc Feeley, All Rights Reserved.
 
 ;;;============================================================================
 
@@ -36,6 +36,8 @@ cond-expand
 define-cond-expand-feature
 case-lambda
 letrec*
+when
+unless
 
 ;; global variable
 default-random-source
@@ -77,6 +79,14 @@ bitwise-xor
 box
 box?
 break
+bytevector
+bytevector-append
+bytevector-copy
+bytevector-copy!
+bytevector-length
+bytevector-u8-ref
+bytevector-u8-set!
+bytevector?
 call-with-input-process
 call-with-input-string
 call-with-input-u8vector
@@ -122,8 +132,10 @@ create-symbolic-link
 current-directory
 current-error-port
 current-exception-handler
+current-jiffy
 current-processor
 current-readtable
+current-second
 current-thread
 current-time
 current-user-interrupt-handler
@@ -156,6 +168,9 @@ error
 error-exception-message
 error-exception-parameters
 error-exception?
+exact
+exact-integer?
+exact-integer-sqrt
 exit
 expression-parsing-exception-kind
 expression-parsing-exception-parameters
@@ -166,6 +181,7 @@ f32vector
 f32vector->list
 f32vector-append
 f32vector-copy
+f32vector-copy!
 f32vector-fill!
 f32vector-length
 f32vector-ref
@@ -177,6 +193,7 @@ f64vector
 f64vector->list
 f64vector-append
 f64vector-copy
+f64vector-copy!
 f64vector-fill!
 f64vector-length
 f64vector-ref
@@ -269,6 +286,7 @@ flsquare
 fltan
 fltanh
 fltruncate
+flush-output-port
 flzero?
 fold
 fold-right
@@ -322,6 +340,8 @@ fxzero?
 gc-report-set!
 generate-proper-tail-calls
 gensym
+get-environment-variable
+get-environment-variables
 get-output-string
 get-output-u8vector
 get-output-vector
@@ -341,13 +361,10 @@ host-info-name
 host-info?
 host-name
 identity
-improper-length-list-exception-arg-num
-improper-length-list-exception-arguments
-improper-length-list-exception-procedure
-improper-length-list-exception?
 inactive-thread-exception-arguments
 inactive-thread-exception-procedure
 inactive-thread-exception?
+inexact
 infinite?
 initialized-thread-exception-arguments
 initialized-thread-exception-procedure
@@ -367,7 +384,11 @@ integer-sqrt
 invalid-hash-number-exception-arguments
 invalid-hash-number-exception-procedure
 invalid-hash-number-exception?
+invalid-utf8-encoding-exception-arguments
+invalid-utf8-encoding-exception-procedure
+invalid-utf8-encoding-exception?
 iota
+jiffies-per-second
 join-timeout-exception-arguments
 join-timeout-exception-procedure
 join-timeout-exception?
@@ -379,6 +400,10 @@ keyword-hash
 keyword?
 last
 last-pair
+length-mismatch-exception-arg-num
+length-mismatch-exception-arguments
+length-mismatch-exception-procedure
+length-mismatch-exception?
 link-flat
 link-incremental
 list->f32vector
@@ -400,6 +425,7 @@ mailbox-receive-timeout-exception-arguments
 mailbox-receive-timeout-exception-procedure
 mailbox-receive-timeout-exception?
 main
+make-bytevector
 make-condition-variable
 make-f32vector
 make-f64vector
@@ -582,6 +608,7 @@ s16vector
 s16vector->list
 s16vector-append
 s16vector-copy
+s16vector-copy!
 s16vector-fill!
 s16vector-length
 s16vector-ref
@@ -593,6 +620,7 @@ s32vector
 s32vector->list
 s32vector-append
 s32vector-copy
+s32vector-copy!
 s32vector-fill!
 s32vector-length
 s32vector-ref
@@ -604,6 +632,7 @@ s64vector
 s64vector->list
 s64vector-append
 s64vector-copy
+s64vector-copy!
 s64vector-fill!
 s64vector-length
 s64vector-ref
@@ -615,6 +644,7 @@ s8vector
 s8vector->list
 s8vector-append
 s8vector-copy
+s8vector-copy!
 s8vector-fill!
 s8vector-length
 s8vector-ref
@@ -729,7 +759,12 @@ step-level-set!
 string->keyword
 string->uninterned-keyword
 string->uninterned-symbol
+string->utf8
+string->vector
 string-ci=?-hash
+string-copy!
+string-for-each
+string-map
 string-set
 string-shrink!
 string=?-hash
@@ -769,6 +804,7 @@ subvector
 subvector-fill!
 subvector-move!
 symbol-hash
+symbol=?
 system-stamp
 system-type
 system-type-string
@@ -868,6 +904,7 @@ u16vector
 u16vector->list
 u16vector-append
 u16vector-copy
+u16vector-copy!
 u16vector-fill!
 u16vector-length
 u16vector-ref
@@ -879,6 +916,7 @@ u32vector
 u32vector->list
 u32vector-append
 u32vector-copy
+u32vector-copy!
 u32vector-fill!
 u32vector-length
 u32vector-ref
@@ -890,6 +928,7 @@ u64vector
 u64vector->list
 u64vector-append
 u64vector-copy
+u64vector-copy!
 u64vector-fill!
 u64vector-length
 u64vector-ref
@@ -902,6 +941,7 @@ u8vector->list
 u8vector->object
 u8vector-append
 u8vector-copy
+u8vector-copy!
 u8vector-fill!
 u8vector-length
 u8vector-ref
@@ -955,10 +995,15 @@ user-info-shell
 user-info-uid
 user-info?
 user-name
+utf8->string
+vector->string
 vector-append
 vector-cas!
 vector-copy
+vector-copy!
+vector-for-each
 vector-inc!
+vector-map
 vector-set
 vector-shrink!
 void
@@ -977,6 +1022,10 @@ with-output-to-process
 with-output-to-string
 with-output-to-u8vector
 with-output-to-vector
+write-bytevector
+write-shared
+write-simple
+write-string
 write-substring
 write-subu8vector
 write-u8
